This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Olena, a generic and efficient image processing platform".
The branch next has been updated
via 4c42b800077d0dda5fde111d0e4761661c9a52c3 (commit)
from 68d80d9e1c6f2b66a45e6bb107c7697871386426 (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
4c42b80 Upload only branches master and next, in their own directories.
-----------------------------------------------------------------------
Summary of changes:
ChangeLog | 7 +++++++
lrde-upload.sh | 36 +++++++++++++++++++++++++++++++++---
2 files changed, 40 insertions(+), 3 deletions(-)
hooks/post-receive
--
Olena, a generic and efficient image processing platform
* mln/make/edge_image.hh: Fix Doxygen comments.
(make::edge_image(const Graph<G>&, const fun::i2v::array<V>&))
(make::edge_image(const Graph<G>&, const Function_v2v<FP>&,
const Function_v2v<FV>&))):
Properly build the required p_edges site sets.
(make::edge_image(const vertex_image<P,V,G>&, const Function_v2b<F>&)):
Actually use the predicate passed as second argument.
Remove debug code.
---
milena/ChangeLog | 13 +++++++++++++
milena/mln/make/edge_image.hh | 27 +++++++++++++--------------
2 files changed, 26 insertions(+), 14 deletions(-)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index 39cc7f3..050fb7c 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,3 +1,16 @@
+2010-05-11 Roland Levillain <roland(a)lrde.epita.fr>
+
+ Fix make::edge_image.
+
+ * mln/make/edge_image.hh: Fix Doxygen comments.
+ (make::edge_image(const Graph<G>&, const fun::i2v::array<V>&))
+ (make::edge_image(const Graph<G>&, const Function_v2v<FP>&,
+ const Function_v2v<FV>&))):
+ Properly build the required p_edges site sets.
+ (make::edge_image(const vertex_image<P,V,G>&, const Function_v2b<F>&)):
+ Actually use the predicate passed as second argument.
+ Remove debug code.
+
2010-04-27 Roland Levillain <roland(a)lrde.epita.fr>
Help g++ 3.3 compile Milena code.
diff --git a/milena/mln/make/edge_image.hh b/milena/mln/make/edge_image.hh
index 2a429cb..e964aab 100644
--- a/milena/mln/make/edge_image.hh
+++ b/milena/mln/make/edge_image.hh
@@ -46,7 +46,7 @@ namespace mln
/// Construct an edge image.
///
- /// \param[in] g A graph
+ /// \param[in] g A graph.
/// \param[in] fv A function mapping edge ids to values.
///
/// \return an edge image.
@@ -57,7 +57,7 @@ namespace mln
/// Construct an edge image.
///
- /// \param[in] g A graph
+ /// \param[in] g A graph.
/// \param[in] fv A function mapping edge ids to values.
///
/// \return an edge image.
@@ -69,7 +69,7 @@ namespace mln
/// Construct an edge image.
///
- /// \param[in] g_ A graph
+ /// \param[in] g_ A graph.
/// \param[in] fp A function mapping edge ids to sites.
/// \param[in] fv A function mapping edge ids to values.
///
@@ -86,7 +86,7 @@ namespace mln
/// Construct an edge image.
///
/// \param[in] v_ima_ A vertex image.
- /// \param[in] pe A p_edges mapping graph element to sites .
+ /// \param[in] pe A p_edges mapping graph elements to sites.
/// \param[in] fv_ A function mapping two vertex ids to a value.
/// The result is associated to the corresponding edge.
///
@@ -103,7 +103,7 @@ namespace mln
/// Construct an edge image.
///
/// \param[in] v_ima_ A vertex image.
- /// \param[in] fv_ A function mapping two vertices ids to a value.
+ /// \param[in] fv_ A function mapping two vertices' values to a value.
/// The result is associated to the corresponding edge.
///
/// \return an edge image without localization information mapped to
@@ -118,8 +118,9 @@ namespace mln
/// Construct an edge image.
///
/// \param[in] v_ima_ A vertex image.
/// \param[in] fv_ A function mapping a vertex ids to a value.
/// The result is associated to the corresponding edge.
///
/// \return an edge image without localization information mapped to
/// graph elements.
@@ -142,8 +143,8 @@ namespace mln
trace::entering("make::edge_image");
mln_precondition(exact(g).is_valid());
- p_vertices<G> pv(g);
- mln::edge_image<void,V,G> ima(pv, fv);
+ p_edges<G> pe(g);
+ mln::edge_image<void,V,G> ima(pe, fv);
trace::exiting("make::edge_image");
return ima;
@@ -183,8 +184,8 @@ namespace mln
const G& g = exact(g_);
mln_precondition(g.is_valid());
- p_vertices<G,FP> pv(g,fp);
- mln::edge_image<mln_result(FP),mln_result(FV),G> ima(pv, fv);
+ p_edges<G,FP> pe(g,fp);
+ mln::edge_image<mln_result(FP),mln_result(FV),G> ima(pe, fv);
trace::exiting("make::edge_image");
return ima;
@@ -256,7 +257,6 @@ namespace mln
const v_ima_t& v_ima = exact(v_ima_);
mln_precondition(v_ima.is_valid());
-
p_edges<G> pe(v_ima.domain().graph());
typedef mln::edge_image<void,bool,G> edge_ima_t;
edge_ima_t ima_e(pe);
@@ -269,8 +269,7 @@ namespace mln
typename v_ima_t::edge_win_t win;
mln_qiter(v_ima_t::edge_win_t) q(win, p);
for_all(q)
- std::cout << q << std::endl;
-// ima_e(q) = false;
+ ima_e(q) = false;
}
trace::exiting("make::edge_image");
@@ -118,8 +118,9 @@ namespace mln
///
/// \param[in] v_ima_ A vertex image.
- /// \param[in] fv_ A function mapping a vertex ids to a value.
- /// The result is associated to the corresponding edge.
+ /// \param[in] fv_ A predicate on a vertex's value.
+ /// The (Boolean) result is associated to the
+ /// edges adjacent to the vertex.
///
/// \return an edge image without localization information mapped to
--
1.5.6.5